<?php
/*
 * This is a PHP library that handles calling reCAPTCHA.
 *    - Documentation and latest version
 *          http://recaptcha.net/plugins/php/
 *    - Get a reCAPTCHA API Key
 *          https://www.google.com/recaptcha/admin/create
 *    - Discussion group
 *          http://groups.google.com/group/recaptcha
 *
 * Copyright (c) 2007 reCAPTCHA -- http://recaptcha.net
 * AUTHORS:
 *   Mike Crawford
 *   Ben Maurer
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

// Wrapped into a class by Michael Toppa, so it doesn't interfere with other
// WordPress plugins that may be using recaptcha

/**
 * The reCAPTCHA server URL's
 */

define("_SIGNUPURL", "https://www.google.com/recaptcha/admin");
define("_SITEVERIFYURL", "https://www.google.com/recaptcha/api/siteverify?");
define("_VERSION", "wp_php_1.0");

define("RECAPTCHA_API_SERVER", "http://www.google.com/recaptcha/api");
define("RECAPTCHA_API_SECURE_SERVER", "https://www.google.com/recaptcha/api");
define("RECAPTCHA_VERIFY_SERVER", "www.google.com");

class RecaptchaForDekoBoko {
    /**
     * Encodes the given data into a query string format
     * @param $data - array of string elements to be encoded
     * @return string - encoded request
     */
    public static function _recaptcha_qsencode ($data) {
            $req = "";
            foreach ( $data as $key => $value )
                    $req .= $key . '=' . urlencode( stripslashes($value) ) . '&';

            // Cut the last '&'
            $req=substr($req,0,strlen($req)-1);
            return $req;
    }
    
    /**
     * Submits an HTTP GET to a reCAPTCHA server.
     *
     * @param string $path url path to recaptcha server.
     * @param array  $data array of parameters to be sent.
     *
     * @return array response
     */
    
    public static function _submitHTTPGet($path, $data)
    {
        //file_put_contents("php://stderr","*** RecaptchaForDekoBoko::_submitHTTPGet(): path is $path\r\n");
        //file_put_contents("php://stderr","*** RecaptchaForDekoBoko::_submitHTTPGet(): data is ".print_r($data,true));
        $req = RecaptchaForDekoBoko::_recaptcha_qsencode($data);
        $response = file_get_contents($path . $req);
        //file_put_contents("php://stderr","*** RecaptchaForDekoBoko::_submitHTTPGet(): response is ".print_r($response,true));
        return $response;
    }

    /**
     * Calls the reCAPTCHA siteverify API to verify whether the user passes
     * CAPTCHA test.
     *
     * @param string $remoteIp   IP address of end user.
     * @param string $response   response string from recaptcha verification.
     *
     * @return ReCaptchaResponse
     */
    public static function verifyResponse($secret, $remoteIp, $response)
    {
        // Discard empty solution submissions
        if ($response == null || strlen($response) == 0) {
            $recaptchaResponse = new ReCaptchaResponse();
            $recaptchaResponse->success = false;
            $recaptchaResponse->errorCodes = 'missing-input';
            return $recaptchaResponse;
        }

        $getResponse = RecaptchaForDekoBoko::_submitHttpGet(
            _SITEVERIFYURL,
            array (
                'secret' => $secret,
                'remoteip' => $remoteIp,
                'v' => _VERSION,
                'response' => $response
            )
        );
        $answers = json_decode($getResponse, true);
        $recaptchaResponse = new ReCaptchaResponseForDekoBoko();

        if (trim($answers [success]) == true) {
            $recaptchaResponse->is_valid = true;
        } else {
            $recaptchaResponse->is_valid = false;
            $recaptchaResponse->error = $answers [error-codes];
        }

        return $recaptchaResponse;
    }
    
    
    
    /**
     * Gets the challenge HTML.
     * This is called from the browser, and the resulting reCAPTCHA HTML widget
     * is embedded within the HTML form it was called from.
     * @param string $pubkey A public key for reCAPTCHA
     * @param string $recaptcha_language The language for the reCAPTCHA.
     * @param string $theme The theme for the reCAPTCHA.

     * @return string - The HTML to be embedded in the user's form.
     */
    public static function recaptcha_get_html ($pubkey, $recaptcha_language = 'en', $theme = 'standard')
    {
        // MTT edit - change "die" to "return"
        if ($pubkey == null || $pubkey == '') {
            return ("To use reCAPTCHA you must get an API key from <a href='https://www.google.com/recaptcha/admin/create'>https://www.google.com/recaptcha/admin/create</a>");
        }
        
        return '<div class="g-recaptcha" data-sitekey="' .
            $pubkey .
            '" data-theme="' . $theme .
            '"></div><script type="text/javascript"' .
            'src="https://www.google.com/recaptcha/api.js?hl=' .
            $recaptcha_language .
            '"></script><br clear="all" />';
    }
    
    public static function recaptcha_get_signup_url ($domain = null, $appname = null) {
      return "_SIGNUPURL" . "/create?" .  
      RecaptchaForDekoBoko::_recaptcha_qsencode (array (
                                                        'domains' => $domain, 'app' => $appname));
    }
    

}

/**
 * A ReCaptchaResponse is returned from recaptcha_check_answer()
 */
class ReCaptchaResponseForDekoBoko {
        var $is_valid;
        var $error;
}
?>
